@@ -35,10 +35,12 @@ class Database:
             if response_ok == True:
 
                 if price_adj == False:
-                    ohlc_result = json.loads(json.loads(response.content).replace("'", "\"").replace('False','0').replace('True','1'))
+                    json1 = json.loads(response.content).replace("'", "\"").replace('False','0').replace('True','1').replace('nan','NaN')
+                    ohlc_result = json.loads(json1)
                 else:
+                    json1 = json.loads(response.content).replace("'", "\"").replace('[(', '\"[(').replace(')]',')]\"').replace('False','0').replace('True','1').replace('nan','NaN')
 
-                    result = json.loads(json.loads(response.content).replace("'", "\"").replace('[(', '\"[(').replace(')]',')]\"').replace('False','0').replace('True','1'))
+                    result = json.loads(json1)
                     ohlc_result = result[0]
 
                     qfq_result = result[1].replace('[','').replace(']','').replace(' ','')
@@ -1144,6 +1146,8 @@ class Database:
             json1 = json1.replace('L\"OCCITANE','LOCCITANE')
             json1 = json1.replace('True','\"True\"')
             json1 = json1.replace('False','\"False\"')
+            json1 = json1.replace('\"\"True\"\"','\"True\"')
+            json1 = json1.replace('\"\"False\"\"','\"False\"')
 
             result = json.loads(json1)
 
@@ -1155,9 +1159,12 @@ class Database:
             df['share_issued'] = df['share_issued'].str.replace('-','', regex=False)
             df['share_issued'] = df['share_issued'].astype('int64')
 
+            df['volume'] = df['volume'].str.replace('.0','', regex=False)
+            df['turnover'] = df['turnover'].str.replace('.0','', regex=False)
+            df['market_capital'] = df['market_capital'].str.replace('.0','', regex=False)
+
             df = df.sort_values(by='code')
 
-            #df['market_capital'] = df['market_capital'].map(lambda x:round(x,0))
             df['market_capital'] = df['market_capital'].astype('int64')
             df['is_stop_trading'] = df['is_stop_trading'].map({'1': True, '0': False})
 
